__author__ = "Overcomer"
__version__ = "0.0.7"
__module__ = ["media", "string"]

from .media import check_image, IMAGE_FORMAT
from .media import FPS, VIDEO_FORMAT
from .string import check_bool